@@ -1,14 +1,19 @@
 from abc import ABC, abstractmethod
 from datetime import datetime, timedelta
 from enum import Enum
-from importlib import metadata as importlib_metadata
 import os
 from os import PathLike
 from pathlib import Path
+import sys
 from textwrap import indent
 from typing import Iterator, List, Tuple, Union
 
-from .model.base import (
+if sys.version_info >= (3, 8):
+    from importlib import metadata as importlib_metadata
+else:
+    import importlib_metadata
+
+from nemspy.model.base import (
     AttributeEntry,
     ConnectionEntry,
     EntryType,
@@ -21,7 +26,7 @@ from .model.base import (
     SequenceEntry,
     VerbosityOption,
 )
-from .utilities import create_symlink, LOGGER
+from nemspy.utilities import create_symlink, LOGGER
 
 
 class Earth(AttributeEntry):
